/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.streams.kstream;

import org.apache.kafka.streams.processor.api.Processor;
import org.apache.kafka.streams.processor.api.Record;

/**
 * @deprecated Since 4.0 and should not be used any longer.
 */
@Deprecated
public class ForeachProcessor<K, V> implements Processor<K, V, Void, Void> {

    private final ForeachAction<K, V> action;

    public ForeachProcessor(final ForeachAction<K, V> action) {
        this.action = action;
    }

    @Override
    public void process(final Record<K, V> record) {
        action.apply(record.key(), record.value());
    }
}
